@@ -21,7 +21,9 @@
 #include <errno.h>
 #include <sys/stat.h>
 #include <sys/types.h>
+#include <libintl.h>
 
+#include <glib/gi18n.h>
 #include <libgnomevfs/gnome-vfs.h>
 #include <libgnomevfs/gnome-vfs-cancellable-ops.h>
 #include <libgnomevfs/gnome-vfs-module.h>
@@ -29,7 +31,11 @@
 #include <gnome-theme-info.h>
 
 #define THEME_METHOD_DIRECTORY DIRECTORY_DIR "/theme-method.directory"
-#define _(s) gettext (s)
+
+/* this is from gnome-vfs-monitor-private.h */
+void gnome_vfs_monitor_callback (GnomeVFSMethodHandle *method_handle,
+                                 GnomeVFSURI *info_uri,
+                                 GnomeVFSMonitorEventType event_type);
 
 static void invoke_monitors(gchar *uri, gpointer data);
 
@@ -215,13 +221,13 @@ typedef struct _ThemeHandle ThemeHandle;
 struct _ThemeHandle {
     GnomeVFSMethodHandle *handle;
 
-    // if we're listing themes....
+    /* if we're listing themes.... */
     GList *theme;
     GnomeVFSFileInfoOptions options;
     gboolean seen_dotdirectory;
     
-    // if we're doing a file....
-    gchar *uri; // the real URI
+    /* if we're doing a file.... */
+    gchar *uri; /* the real URI */
 };
 
 /* -- VFS method -- */
@@ -658,31 +664,45 @@ do_monitor_cancel(GnomeVFSMethod *method,
 static GnomeVFSMethod method = {
     sizeof(GnomeVFSMethod),
 
-    .open     = do_open,
-    .create   = do_create,
-    .close    = do_close,
-    .read     = do_read,
-    .write    = do_write,
-    .seek     = do_seek,
-    .tell     = do_tell,
-    .get_file_info_from_handle = do_get_file_info_from_handle,
+    do_open,
+    do_create,
+    do_close,
+    do_read,
+    do_write,
+    do_seek,
+    do_tell,
 
-    .open_directory  = do_open_directory,
-    .close_directory = do_close_directory,
-    .read_directory  = do_read_directory,
+    NULL,
 
-    .get_file_info = do_get_file_info,
-    .is_local      = do_is_local,
-    .unlink        = do_unlink,
+    do_open_directory,
+    do_close_directory,
+    do_read_directory,
+    do_get_file_info,
+    do_get_file_info_from_handle,
+    do_is_local,
 
-    .monitor_add = do_monitor_add,
-    .monitor_cancel = do_monitor_cancel
+    NULL,
+    NULL,
+    NULL,
+
+    do_unlink,
+
+    NULL,
+    NULL,
+    NULL,
+    NULL,
+    NULL,
+
+    do_monitor_add,
+    do_monitor_cancel,
+
+    NULL
 };
 
 GnomeVFSMethod*
 vfs_module_init (const char *method_name, const char *args)
 {
-	gnome_theme_init (FALSE);
+	gnome_theme_init (NULL);
 	if (!strcmp (method_name, "themes"))
 	{
 		gnome_theme_info_register_theme_change ((GFunc)invoke_monitors, NULL);
